@@ -299,14 +299,17 @@ class TaskScheduler:
         # loop = asyncio.get_event_loop()
         loop = asyncio.new_event_loop()
         asyncio.set_event_loop(loop)
+        bprint(f"New loop on ipt {ipt}")
         tasks = []
         self.assigned_tasks[ipt] = {}
         new_dict = {}
+        # inicia n tareas en proceados
         for i in range(self.lnproc):
             ico = self.set_ico()
             nd = {ico:  None}
             new_dict.update(nd)
         self.assigned_tasks[ipt] = new_dict
+        bprint(f"Tareas asignada {new_dict}")
         tasks_on_this_ipt = self.assigned_tasks.get(ipt)
         stax, sta_kwargs = self.set_init_args_kwargs(ipt)
         bprint(f"ipt {ipt} Args inputy {stax}")
